#!/usr/bin/python
# encoding: utf-8
"""
==========================商品主图裁剪==========================
"""
import requests
import json
import base64
import hashlib


class Idphoto:
    def __init__(self, appcode, timeout=7):
        self.appcode = appcode
        self.timeout = timeout

        self.commonseg_rgba_url = "https://ecimage.market.alicloudapi.com/commodity/crop"

        self.headers = {
            'Authorization': 'APPCODE ' + appcode,
        }

    def get_md5_data(self, body):
        """
        md5加密
        :param body_json:
        :return:
        """

        md5lib = hashlib.md5()
        md5lib.update(body.encode("utf-8"))
        body_md5 = md5lib.digest()
        body_md5 = base64.b64encode(body_md5)
        return body_md5

    def get_photo_base64(self, file_path):
        with open(file_path, 'rb') as fp:
            photo_base64 = base64.b64encode(fp.read())

        photo_base64 = photo_base64.decode('utf8')
        return photo_base64

    def aiseg_request(self, url, data, headers):
        resp = requests.post(url=url, data=data, headers=headers, timeout=self.timeout)
        res = {"status_code": resp.status_code}
        try:
            res["data"] = json.loads(resp.text)
            return res
        except Exception as e:
            print(e)

    def commodity_crop(self, file_path):
        """
        商品主图裁剪
        :return:
        """
        photo_base64 = self.get_photo_base64(file_path)
        body_json = {
            "photo": photo_base64,
            "output_size": [640, 800],  # 输出图的尺寸，格式为整形数组：[640, 800]，或者为字符串："640x800",
            "object_ratio": 0.3,  # 商品占比，浮点，范围为(0, 1.0]
            "padding_mode": 0,
            # 补边模式，为0或者1，默认为0，当原图宽度或者高度不够时，回采取补边的方式，模式0为补充的颜色为背景色均值，模式1为拉伸补边方式，在背景比较纯色，没有杂物的情况下，建议采取模式1
        }

        body = json.dumps(body_json)
        body_md5 = self.get_md5_data(body=body)

        self.headers.update({'Content-MD5': body_md5})

        data = self.aiseg_request(url=self.commonseg_rgba_url, data=body, headers=self.headers)
        return data


if __name__ == "__main__":
    file_path = "1.jpg"

    idphoto = Idphoto(appcode="你的appcode")

    d = idphoto.commodity_crop(file_path)
    print(d)
